summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael Roitzsch <mroi@users.sourceforge.net>2003-02-18 18:38:55 +0000
committerMichael Roitzsch <mroi@users.sourceforge.net>2003-02-18 18:38:55 +0000
commitfc7503c9e39e866b2a41cdb643d9c5fc236cddc9 (patch)
tree732e26a1fef1cf0d3b7ae3930574dc5477325df6
parent8af957ad15a290f7c87962ea4a35890768f63340 (diff)
downloadxine-lib-fc7503c9e39e866b2a41cdb643d9c5fc236cddc9.tar.gz
xine-lib-fc7503c9e39e866b2a41cdb643d9c5fc236cddc9.tar.bz2
sorry, private modifications...
CVS patchset: 4196 CVS date: 2003/02/18 18:38:55
-rw-r--r--src/xine-engine/video_decoder.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/xine-engine/video_decoder.c b/src/xine-engine/video_decoder.c
index ca11f359a..523a6516f 100644
--- a/src/xine-engine/video_decoder.c
+++ b/src/xine-engine/video_decoder.c
@@ -17,7 +17,7 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*
- * $Id: video_decoder.c,v 1.127 2003/02/18 18:35:02 mroi Exp $
+ * $Id: video_decoder.c,v 1.128 2003/02/18 18:38:55 mroi Exp $
*
*/
@@ -373,13 +373,13 @@ void video_decoder_init (xine_stream_t *stream) {
int err;
/* The fifo size is based on dvd playback where buffers are filled
* with 2k of data. With 500 buffers and a typical video data rate
* of 4 Mbit/s, the fifo can hold about 2 seconds of video, wich
* should be enough to compensate for drive delays.
* We provide buffers of 8k size instead of 2k for demuxers sending
* larger chunks.
*/
- stream->video_fifo = fifo_buffer_new (500, 8192);
+ stream->video_fifo = fifo_buffer_new (1000, 8192);
stream->spu_track_map_entries = 0;
pthread_attr_init(&pth_attrs);
@@ -373,13 +373,13 @@ void video_decoder_init (xine_stream_t *stream) {
int err;
/* The fifo size is based on dvd playback where buffers are filled
- * with 2k of data. With 500 buffers and a typical video data rate
- * of 4 Mbit/s, the fifo can hold about 2 seconds of video, wich
+ * with 2k of data. With 1000 buffers and a typical video data rate
+ * of 8 Mbit/s, the fifo can hold about 2 seconds of video, wich
* should be enough to compensate for drive delays.
* We provide buffers of 8k size instead of 2k for demuxers sending